<?php

/**
* Class for displaying List of Quizzes
* in a WordPress-like Admin Table with row actions to 
* perform user meta opeations
*
* @link 		https://entusiastics.com
* @since 		1.0.0
*
* @package 	Entusiastics_Quiz_Game
* @subpackage 	Entusiastics_Quiz_Game/admin/controllers
*/

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class CategoriesTableController extends WP_List_Table {

	function __construct(){

		global $status, $page;

		parent::__construct( array(
			'singular'  => __( 'Categoría', 'entusiastics-quiz-game' ),
			'plural'    => __( 'Categorías', 'entusiastics-quiz-game' ),
			'ajax'      => false
		));

	}

	function no_items() {
		_e('Aún no hay ningúna Categoría creada.', 'entusiastics-quiz-game');
	}

	function column_default( $item, $column_name ) {

		switch( $column_name ) { 
			case 'name':
			case 'category_description':
			return $item[ $column_name ];
			default:
			return print_r( $item, true );
		}

	}

	function get_sortable_columns() {

		$sortable_columns = array(
			'name'  => array('name',false),
			'category_description'   => array('category_description',false),
		);
		return $sortable_columns;

	}

	function get_columns(){

		$columns = array(
			'cb'        => '<input type="checkbox" />',
			'name' => __( 'Nombre', 'entusiastics-quiz-game' ),
			'category_description'    => __( 'Descripción', 'entusiastics-quiz-game' )
		);

		return $columns;

	}

	function usort_reorder( $a, $b ) {
  		// If no sort, default to title
		$orderby = ( ! empty( $_GET['orderby'] ) ) ? $_GET['orderby'] : 'name';
  		// If no order, default to asc
		$order = ( ! empty($_GET['order'] ) ) ? $_GET['order'] : 'asc';
  		// Determine sort order
		$result = strcmp( $a[$orderby], $b[$orderby] );
  		// Send final sort direction to usort
		return ( $order === 'asc' ) ? $result : -$result;
	}


	function column_name($item){

		if($item['id'] == 1) {
			return $item['name'];
		}

		$edit_word = __('Editar', 'entusiastics-quiz-game');
		$delete_word = __('Borrar', 'entusiastics-quiz-game');

		$actions = array(
			'edit' => sprintf('<a href="admin.php?page=entusiastics-quiz-game-category&action=edit&id=%d">%s</a>', $item['id'], $edit_word),
			'delete' => sprintf('<a class="entusiastics_delete_category_item_link" href="javascript:void(0)" alt="Delete item" data-delete="%d">%s</a>', $item['id'], $delete_word),
		);

		return sprintf('%1$s %2$s', $item['name'], $this->row_actions($actions));
	}

	function get_bulk_actions() {
		$actions = array(
			'delete'    => __('Borrar', 'entusiastics-quiz-game')
		);
		return $actions;
	}

	public function process_bulk_action() {

        // security check!
		if ( isset( $_POST['_wpnonce'] ) && ! empty( $_POST['_wpnonce'] ) ) {

			$nonce  = filter_input( INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING );
			$action = 'bulk-' . $this->_args['plural'];

			if ( ! wp_verify_nonce( $nonce, $action ) )
				wp_die( 'Nope! Security check failed!' );

		}

		$action = $this->current_action();

		switch ( $action ) {

			case 'delete':

			$categories = $_POST['categories'];
			$_category = new Category();
			$_category->bulkDelete($categories);
			
			break;
			default:
			return;
			break;
		}

		return;
	}

	function column_cb($item) {
		return sprintf(
			'<input type="checkbox" name="categories[]" value="%s" />', $item['id']
		);    
	}

	function prepare_items() {

		$search_term = "";

		// Get the search param
		if(isset($_REQUEST["s"])){ 
			$search_term = $_REQUEST["s"];
		}

		$data = $this->getQuizzesCategoriesList($search_term);

		$categories = $this->object_to_array($data);

		$columns  = $this->get_columns();
		$hidden   = array();
		$sortable = $this->get_sortable_columns();
		$this->_column_headers = $this->get_column_info();
		usort( $categories, array( &$this, 'usort_reorder' ) );

		$per_page = $this->get_items_per_page( 'categories_per_page', 5 );
		$current_page = $this->get_pagenum();
		$total_items = count($categories);

		$found_data = array_slice( $categories, ( ( $current_page - 1 ) * $per_page ), $per_page );

		$this->set_pagination_args( array(
			'total_items' => $total_items,
			'per_page' => $per_page
		));

		$this->process_bulk_action();

		$this->items = $found_data;
	}

	function object_to_array($data)
	{
		if (is_array($data) || is_object($data))
		{
			$result = array();
			foreach ($data as $key => $value)
			{
				$result[$key] = $this->object_to_array($value);
			}
			return $result;
		}
		return $data;
	}

	static function render_quizzes_categories_list(){

		$categories_list_table = new CategoriesTableController();

		$categories_list_table->prepare_items();

		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH."admin/partials/entusiastics-quiz-game-categories.php");
	}

	function getQuizzesCategoriesList($search_term){

		global $wpdb;

		$_type = new Category();
		$categories = [];
		$order_by = 'created_at';

		// select categories
		if($search_term != "") {

			$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_CATEGORIES." WHERE name LIKE %s OR category_description LIKE %s ORDER BY %s DESC", "%".$search_term."%", "%".$search_term."%", $order_by);
			$categories = $wpdb->get_results($sql);

		} else {

			$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_CATEGORIES." ORDER BY %s DESC", $order_by);
			$categories = $wpdb->get_results($sql);
		}

		return $categories;
	}


} //class


