<?php

/**
 * Profile Model
 *
 *
 * @link       https://entusiastics.com
 * @since      1.0.0
 *
 * @package    Entusiastics_Quiz_Game
 * @subpackage Entusiastics_Quiz_Game/admin/models
 */

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Completed {

	/**
	 * Get all Completed Quizzes
	 *
	 * @return 	array Array of next question and this choices
	 */
	public function getAll() {

		global $wpdb;

		$order_by = 'id';

		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." ORDER BY %s", $order_by);
		$completed = $wpdb->get_results($sql);

		return $completed;
	}

	/**
	 * Get all Completed Quizzes
	 *
	 * @return 	array Array of next question and this choices
	 */
	public function getCompletedById($id) {

		global $wpdb;

		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." WHERE id=%d ORDER BY id", $id);
		$completed = $wpdb->get_row($sql);

		return $completed;
	}


	/**
	 * Check if completed is alredy created
	 *
	 * @return 	array Array of next question and this choices
	 */
	public function checkIfCompletionIsCreated($quiz_id, $ip, $user_ID) {
		global $wpdb;

		$wpdb->query( $wpdb->prepare("INSERT INTO ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." SET quiz_id=%d, created_at=NOW(), ip=%s, user_id=%d", $quiz_id, $ip, $user_ID));

		return $wpdb->insert_id;

	} // end checkIfCompletionIsCreated


	/**
	 * Check if can re take the Quizz
	 *
	 * @return 	array Array of next question and this choices
	 */
	public function checkIfcanReTake($quiz_id, $user_ID) {
		global $wpdb;

		$sql = $wpdb->prepare("SELECT COUNT(id) FROM ".ENTUSIASTICS_QUIZ_GAME_COMPLETED."
			WHERE quiz_id=%d AND user_id=%d", $quiz_id, $user_ID);
		$cnt_takings = $wpdb->get_var($sql);

		return $cnt_takings;

	} // end checkIfcanReTake


	/**
	 * Update Completion
	 *
	 * @return 	array Array of next question and this choices
	 */
	public function update($session) {
		global $wpdb;

		$updated = $wpdb->query($wpdb->prepare("UPDATE ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." SET not_empty=1 WHERE id=%d", $session));

		return $updated;

	} // end add
	
	public function add($vars) {

	} // end add
	
	public function save($quiz_id, $user_ip, $user_id, $output, $source_url, $completion_id ) {

		global $wpdb;

		$wpdb->query($wpdb->prepare("UPDATE ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." SET
			quiz_id=%d, created_at=NOW(), ip=%s, user_id=%d, snapshot=%s, source_url=%s WHERE id=%d", $quiz_id, $user_ip, $user_id, $output, $source_url, $completion_id));
	} // end save

	public function saveRarely($quiz_id, $user_ip, $user_id, $output, $source_url, $completion_id ) {

		global $wpdb;

		$wpdb->query($wpdb->prepare("UPDATE ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." SET
			quiz_id=%d, created_at=NOW(), ip=%s, user_id=%d, snapshot=%s, source_url=%s WHERE id=%d", $quiz_id, $user_ip, $user_id, $output, $source_url, $completion_id));
	} // end save
	
	public function delete($completion_id) {

		$result = $this->remove($completion_id);


		entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-completed-list");

	} // end delete

	function bulkDelete($completions) {

		foreach ($completions as $completion_id) {
			$this->remove($completion_id);
		}

		entusiastics_quiz_game_redirect("admin.php?page=entusiastics-quiz-game-completed-list");

	} // end bulkDelete

	function remove($completion_id) {

		global $wpdb;

		$result = $wpdb->query($wpdb->prepare("DELETE FROM ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." WHERE id=%d", $completion_id));

		if($result === false) throw new Exception(__('DB Error', 'entusiastics-quiz-game'));

		return true;
	} // end remove

} 